@@ -24,5 +24,5 @@ for(i in 1:2){
 }
 Axis(x =NULL, at = c(1,2,3,4,5,6),side=2, labels = c("Satt","GI","Satt","GI","Satt","GI"))
 #
-}   # end of RRgraph *****************************************************************
+}   # end of RRgraph *************************************************************************************************
 
